import 'package:google_sign_in/google_sign_in.dart';
import 'social_plugin.dart';

class AuthGmail implements SocialLogin {
  static final AuthGmail _instance = AuthGmail.internal();
  GoogleSignIn _googleSignIn;

  factory AuthGmail() {
    return _instance;
  }

  @override
  AuthGmail.internal() {
    _googleSignIn =  GoogleSignIn();
  }

  @override
  Future<bool> isLoggedIn() {
    return _googleSignIn.isSignedIn();
  }

  @override
  Future<AuthResult> login() async {
    await _googleSignIn.signOut(); // force logout
    try {
      final googleSignInAccount = await _googleSignIn.signIn();
      if(googleSignInAccount == null){
        return AuthResult(
            loginStatus: LoginStatus.cancelledByUser,
            accessToken: null
        );
      }
      final googleSignInAuthentication =
      await googleSignInAccount.authentication;
      return AuthResult(
        loginStatus: LoginStatus.loggedIn,
        accessToken: googleSignInAuthentication.accessToken,
      );
    } catch (e) {
      return AuthResult(
        loginStatus: LoginStatus.error,
        accessToken: null,
      );
    }
  }

  @override
  Future<void> logout() {
    return _googleSignIn.signOut();
  }
}
